<?php
/**
 * Courses Section options
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */

// Add Courses section
$wp_customize->add_section( 'raise_charity_pro_courses_section', array(
	'title'             => esc_html__( 'Courses','raise-charity-pro' ),
	'description'       => esc_html__( 'Courses Section options.', 'raise-charity-pro' ),
	'panel'             => 'raise_charity_pro_front_page_panel',
) );

// Courses content enable control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[courses_section_enable]', array(
	'default'			=> 	$options['courses_section_enable'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Raise_Charity_Pro_Switch_Control( $wp_customize, 'raise_charity_pro_theme_options[courses_section_enable]', array(
	'label'             => esc_html__( 'Courses Section Enable', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_courses_section',
	'on_off_label' 		=> raise_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[courses_section_enable]', array(
		'selector'            => '#course-section .tooltiptext',
		'settings'            => 'raise_charity_pro_theme_options[courses_section_enable]',
    ) );
}

// Courses btn label setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[courses_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['courses_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[courses_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'raise-charity-pro' ),
	'section'        	=> 'raise_charity_pro_courses_section',
	'active_callback' 	=> 'raise_charity_pro_is_courses_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[courses_title]', array(
		'selector'            => '#course-section h2.section-title',
		'settings'            => 'raise_charity_pro_theme_options[courses_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'raise_charity_pro_courses_title_partial',
    ) );
}

// Courses btn label setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[courses_sub_title]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['courses_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[courses_sub_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'raise-charity-pro' ),
	'section'        	=> 'raise_charity_pro_courses_section',
	'active_callback' 	=> 'raise_charity_pro_is_courses_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[courses_sub_title]', array(
		'selector'            => '#course-section p.section-subtitle',
		'settings'            => 'raise_charity_pro_theme_options[courses_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'raise_charity_pro_courses_sub_title_partial',
    ) );
}

// content type control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[courses_count]', array(
	'default'          	=> $options['courses_count'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_number_range',
	'validate_callback' => 'raise_charity_pro_validate_courses_count',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[courses_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'raise-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 30. Please input the valid number and save. Then refresh the page to see the change.', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_courses_section',
	'active_callback'   => 'raise_charity_pro_is_courses_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 30,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'raise_charity_pro_theme_options[courses_excerpt_length]', array(
	'sanitize_callback' => 'raise_charity_pro_sanitize_number_range',
	'validate_callback' => 'raise_charity_pro_validate_long_excerpt',
	'default'			=> $options['courses_excerpt_length'],
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[courses_excerpt_length]', array(
	'label'       		=> esc_html__( 'Latest Post Excerpt Length', 'raise-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in latest posts.', 'raise-charity-pro' ),
	'section'     		=> 'raise_charity_pro_courses_section',
	'active_callback' 	=> 'raise_charity_pro_is_courses_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Courses btn label setting and control
$wp_customize->add_setting( 'raise_charity_pro_theme_options[courses_btn_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['courses_btn_text'],
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[courses_btn_text]', array(
	'label'           	=> esc_html__( 'Button Label', 'raise-charity-pro' ),
	'section'        	=> 'raise_charity_pro_courses_section',
	'active_callback' 	=> 'raise_charity_pro_is_courses_section_enable',
	'type'				=> 'text',
) );

// Courses content type control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[courses_content_type]', array(
	'default'          	=> $options['courses_content_type'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[courses_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_courses_section',
	'type'				=> 'select',
	'active_callback' 	=> 'raise_charity_pro_is_courses_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'raise-charity-pro' ),
		'post'      => esc_html__( 'Post', 'raise-charity-pro' ),
		'category'  => esc_html__( 'Category', 'raise-charity-pro' ),
		),
) );

for ( $i = 1; $i <= $options['courses_count']; $i++ ) :
	// latest_posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[courses_content_page_' . $i . ']', array(
		'sanitize_callback' => 'raise_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[courses_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'raise-charity-pro' ), $i ),
		'section'           => 'raise_charity_pro_courses_section',
		'choices'			=> raise_charity_pro_page_choices(),
		'active_callback'	=> 'raise_charity_pro_is_courses_section_content_page_enable',
	) ) );

	// latest_posts posts drop down chooser control and setting
	$wp_customize->add_setting( 'raise_charity_pro_theme_options[courses_content_post_' . $i . ']', array(
		'sanitize_callback' => 'raise_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Chooser( $wp_customize, 'raise_charity_pro_theme_options[courses_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'raise-charity-pro' ), $i ),
		'section'           => 'raise_charity_pro_courses_section',
		'choices'			=> raise_charity_pro_post_choices(),
		'active_callback'	=> 'raise_charity_pro_is_courses_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'raise_charity_pro_theme_options[courses_content_category]', array(
	'sanitize_callback' => 'raise_charity_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'raise_charity_pro_theme_options[courses_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'raise-charity-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_courses_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'raise_charity_pro_is_courses_section_content_category_enable'
) ) );