<?php
/**
 * latest_products Section options
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */

// Add latest_products section
$wp_customize->add_section( 'raise_charity_pro_latest_products_section', array(
	'title'             => esc_html__( 'Latest Products','raise-charity-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'raise-charity-pro' ),
	'panel'             => 'raise_charity_pro_front_page_panel',
) );

// latest_products content enable control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[latest_products_section_enable]', array(
	'default'			=> 	$options['latest_products_section_enable'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Raise_Charity_Pro_Switch_Control( $wp_customize, 'raise_charity_pro_theme_options[latest_products_section_enable]', array(
	'label'             => esc_html__( 'Latest Products Section Enable', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_latest_products_section',
	'on_off_label' 		=> raise_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'raise_charity_pro_theme_options[latest_products_section_enable]', array(
		'selector'            => '#latest-products .tooltiptext',
		'settings'            => 'raise_charity_pro_theme_options[latest_products_section_enable]',
    ) );
}

// Servuce count number control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[latest_products_count]', array(
	'default'          	=> $options['latest_products_count'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_number_range',
	'validate_callback' => 'raise_charity_pro_validate_latest_products_count',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[latest_products_count]', array(
	'label'             => esc_html__( 'Number of Latest Productss Posts', 'raise-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_latest_products_section',
	'active_callback'   => 'raise_charity_pro_is_latest_products_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Recent Cause column layout control and setting
$wp_customize->add_setting( 'raise_charity_pro_theme_options[latest_products_column_layout]', array(
	'default'          	=> $options['latest_products_column_layout'],
	'sanitize_callback' => 'raise_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'raise_charity_pro_theme_options[latest_products_column_layout]', array(
	'label'             => esc_html__( 'Column Layout', 'raise-charity-pro' ),
	'section'           => 'raise_charity_pro_latest_products_section',
	'type'				=> 'select',
	'active_callback' 	=> 'raise_charity_pro_is_latest_products_section_enable',
	'choices'			=> array(
            'col-2'      => esc_html__( 'Two Column', 'raise-charity-pro' ),
            'col-3'      => esc_html__( 'Three Column', 'raise-charity-pro' ),
        )
) );

for ( $i = 1; $i <= $options['latest_products_count']; $i++ ) :

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'raise_charity_pro_theme_options[latest_products_content_latest_products_category_'.$i.']', array(
		'sanitize_callback' => 'absint',
		) ) ;

$wp_customize->add_control( new Raise_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'raise_charity_pro_theme_options[latest_products_content_latest_products_category_'.$i.']', array(
	'label'             => esc_html__( 'Select Latest Products Category ', 'raise-charity-pro' ).$i,
	'section'           => 'raise_charity_pro_latest_products_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'raise_charity_pro_is_latest_products_section_enable'
	) ) );

endfor;
