<?php
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Raise Charity Pro
 * @since Raise Charity Pro 1.0.0
 */
if ( ! function_exists( 'raise_charity_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since Raise Charity Pro 1.0.0
    */
    function raise_charity_pro_add_testimonial_section() {
        $options = raise_charity_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'raise_charity_pro_section_status', true, 'testimonial_section_enable' );

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'raise_charity_pro_filter_testimonial_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render testimonial section now.
        raise_charity_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'raise_charity_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Raise Charity Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function raise_charity_pro_get_testimonial_section_details( $input ) {
        $options = raise_charity_pro_get_theme_options();

        // Content type.
        $testimonial_content_type  = $options['testimonial_content_type'];
        $testimonial_count = !empty( $options['testimonial_count'] ) ? $options['testimonial_count'] : 4;
        $content = array();
        switch ( $testimonial_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) ) :
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) ) :
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['testimonial_content_category'] ) ? $options['testimonial_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $testimonial_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = raise_charity_pro_trim_content( $options['testimonial_excerpt_length'] );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'raise_charity_pro_filter_testimonial_section_details', 'raise_charity_pro_get_testimonial_section_details' );


if ( ! function_exists( 'raise_charity_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since Raise Charity Pro 1.0.0
   *
   */
   function raise_charity_pro_render_testimonial_section( $content_details = array() ) {
        $options = raise_charity_pro_get_theme_options();
        $autoplay = $options['testimonial_auto_play'] ? 'true' : 'false';
        $image = !empty( $options['testimonial_bg_image'] ) ? $options['testimonial_bg_image'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="testimonial-section" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    raise_charity_pro_section_tooltip( 'testimonial-section' );
                    endif; ?>
                    <div class="testimonial-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": <?php echo esc_attr( $autoplay ); ?>, "draggable": true, "fade": false }'>
                        
                        <?php $i = 1 ; foreach ( $content_details as $content ) : ?>

                        <article>
                            <div class="testimonial-item">
                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="testimonial <?php echo esc_attr( $i+1 ); ?>"></a>
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        <?php if ( !empty($options['testimonial_author_position_'.$i]) ): ?>
                                        <span class="testimonial-position"><?php echo esc_html( $options['testimonial_author_position_'.$i] ) ?></span>
                                    <?php endif; ?>
                                    </header>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                    <?php echo raise_charity_pro_get_svg( array( 'icon' => 'quote' ) ); ?>
                                </div><!-- .entry-container -->
                            </div><!-- .testimonial-item -->
                        </article>

                        <?php $i++ ; endforeach ; ?>


                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #testimonial-section -->
       

    <?php }
endif;
